local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus
local rune = x.Rune
local target = x.Target

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.spells["auto_attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.EnemyDetected, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["dark_command"] = {
	ID = 56222--[[Dark Command]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 ) and x.EnemyDetected and s.UnitInfo("target") ~= "player" and x.InstanceType ~= "pvp"
	end,
	NoGCD = true,
	FlashColor = "Purple",
}

a.spells["mind_freeze"] = {
	ID = 47528--[[Mind Freeze]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["arcane_torrent,if=runic_power.deficit>20"] = {
	ID = 50613--[[Arcane Torrent]],
	NoGCD = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and x.RunicPowerDeficit > 20
	end,
	FlashColor = "Yellow",
}

a.spells["blood_fury"] = {
	ID = 20572--[[Blood Fury]],
	NoGCD = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD
	end,
	FlashColor = "Yellow",
}

a.spells["berserking,if=buff.dancing_rune_weapon.up"] = {
	ID = 26297--[[Berserking]],
	NoGCD = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and buff.dancing_rune_weapon.up_nogcd
	end,
	FlashColor = "Yellow",
}

,"use_items"
,"use_item,name=archimondes_hatred_reborn,if=buff.vampiric_blood.up"
,"potion,if=buff.dancing_rune_weapon.up"

a.spells["dancing_rune_weapon,if=(!talent.blooddrinker.enabled|!cooldown.blooddrinker.ready)"] = {
	ID = 49028--[[Dancing Rune Weapon]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and (not talent.blooddrinker.enabled or not cooldown.blooddrinker.ready)
	end,
}

a.spells["tombstone,if=buff.bone_shield.stack>=7"] = {
	ID = 219809--[[Tombstone]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.InCombat and talent.tombstone.enabled and buff.bone_shield.stack >= 7
	end,
}

a.spells["death_strike,if=damage_spike"] = {
	ID = 49998--[[Death Strike]],
	FlashBlink = true,
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.HealthPercent < 90 and s.IncomingDamage(5000 - x.GCD * 1000) > x.MaxHealth * 0.25
	end,
}

a.spells["death_strike,if=runic_power.deficit<10"] = {
	ID = 49998--[[Death Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.RunicPowerDeficit < 10
	end,
}

a.spells["blood_boil,if=!dot.blood_plague.ticking"] = {
	ID = 50842--[[Blood Boil]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.InCombat and not dot.blood_plague.ticking
	end,
}

a.spells["blooddrinker,if=!buff.dancing_rune_weapon.up"] = {
	ID = 206931--[[Blooddrinker]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.InCombat and not buff.dancing_rune_weapon.up and talent.blooddrinker.enabled
	end,
}

a.spells["marrowrend,if=buff.bone_shield.remains<=gcd*2"] = {
	ID = 195182--[[Marrowrend]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return buff.bone_shield.remains <= x.MaxGCD * 2
	end,
}

a.spells["blood_boil,if=charges_fractional>=1.8&buff.haemostasis.stack<5&(buff.haemostasis.stack<3|!buff.dancing_rune_weapon.up)"] = {
	ID = 50842--[[Blood Boil]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.InCombat and cooldown.blood_boil.charges_fractional >= 1.8 and buff.haemostasis.stack < 5 and (buff.haemostasis.stack < 3 or not buff.dancing_rune_weapon.up)
	end,
}

a.spells["marrowrend,if=(buff.bone_shield.stack<5&talent.ossuary.enabled)|buff.bone_shield.remains<gcd*3"] = {
	ID = 195182--[[Marrowrend]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return (buff.bone_shield.stack < 5 and talent.ossuary.enabled) or buff.bone_shield.remains < x.MaxGCD * 3
	end,
}

a.spells["bonestorm,if=runic_power>=100&spell_targets.bonestorm>=3"] = {
	ID = 194844--[[Bonestorm]],
	Melee = true,
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.InCombat and talent.bonestorm.enabled and x.RunicPower >= 100 and x.ActiveEnemies >= 3
	end,
}

a.spells["death_strike,if=buff.blood_shield.up|(runic_power.deficit<15&(runic_power.deficit<25|!buff.dancing_rune_weapon.up))"] = {
	ID = 49998--[[Death Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return buff.blood_shield.up or (x.RunicPowerDeficit < 15 and (x.RunicPowerDeficit < 25 or not buff.dancing_rune_weapon.up))
	end,
}

a.spells["heart_strike,if=buff.dancing_rune_weapon.up"] = {
	ID = 206930--[[Heart Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return buff.dancing_rune_weapon.up
	end,
}

a.spells["death_and_decay,if=buff.crimson_scourge.up"] = {
	ID = 43265--[[Death and Decay]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.EnemyDetected and buff.crimson_scourge.up
	end,
}

a.spells["death_and_decay"] = {
	ID = 43265--[[Death and Decay]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.EnemyDetected and (not x.InCombat or target.time_to_die > 10 or x.ActiveEnemies >= 3)
	end,
}

a.spells["heart_strike,if=rune.time_to_3<gcd|buff.bone_shield.stack>6"] = {
	ID = 206930--[[Heart Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return rune.time_to_3 < x.MaxGCD or buff.bone_shield.stack > 6
	end,
}

